@@ -22,6 +22,7 @@
     .factory('horizon.dashboard.identity.roles.actions.edit.service', editService);
 
   editService.$inject = [
+    '$q',
     'horizon.dashboard.identity.roles.resourceType',
     'horizon.dashboard.identity.roles.role-schema',
     'horizon.app.core.openstack-service-api.keystone',
@@ -37,6 +38,7 @@
    * @Description A service to handle the Edit Role modal.
    */
   function editService(
+    $q,
     resourceType,
     schema,
     keystoneAPI,
@@ -58,7 +60,10 @@
     //////////////
 
     function allowed() {
-      return policy.ifAllowed({ rules: [['identity', 'identity:update_role']] });
+      return $q.all([
+        keystoneAPI.canEditIdentity('role'),
+        policy.ifAllowed({ rules: [['identity', 'identity:update_role']] })
+      ]);
     }
 
     function perform(role) {
@@ -70,7 +75,8 @@
         title: gettext('Edit Role'),
         schema: schema,
         form: ['*'],
-        model: response.data
+        model: response.data,
+        size: 'sm'
       };
       return modalFormService.open(config).then(service.submit);
     }
