@@ -496,10 +496,6 @@ def data(TEST):
                    'description': 'NotDefault',
                    'id': '443a4d7a-4bd2-4474-9a77-02b35c9f8c95',
                    'name': 'another_group'}
-    sec_group_empty = {'tenant_id': '1',
-                       'description': 'SG without rules',
-                       'id': 'f205f3bc-d402-4e40-b004-c62401e19b4b',
-                       'name': 'empty_group'}
 
     def add_rule_to_group(secgroup, default_only=True):
         rule_egress_ipv4 = {
@@ -509,7 +505,9 @@ def data(TEST):
             'protocol': None, 'remote_group_id': None,
             'remote_ip_prefix': None,
             'security_group_id': secgroup['id'],
-            'tenant_id': secgroup['tenant_id']}
+            'tenant_id': secgroup['tenant_id'],
+            'description': "Egrress IPv4 rule",
+        }
         rule_egress_ipv6 = {
             'id': uuidutils.generate_uuid(),
             'direction': u'egress', 'ethertype': u'IPv6',
@@ -517,8 +515,9 @@ def data(TEST):
             'protocol': None, 'remote_group_id': None,
             'remote_ip_prefix': None,
             'security_group_id': secgroup['id'],
-            'tenant_id': secgroup['tenant_id']}
-
+            'tenant_id': secgroup['tenant_id'],
+            'description': 'Egress IPv6 rule',
+        }
         rule_tcp_80 = {
             'id': uuidutils.generate_uuid(),
             'direction': u'ingress', 'ethertype': u'IPv4',
@@ -526,7 +525,9 @@ def data(TEST):
             'protocol': u'tcp', 'remote_group_id': None,
             'remote_ip_prefix': u'0.0.0.0/0',
             'security_group_id': secgroup['id'],
-            'tenant_id': secgroup['tenant_id']}
+            'tenant_id': secgroup['tenant_id'],
+            'description': 'Ingress HTTP',
+        }
         rule_icmp = {
             'id': uuidutils.generate_uuid(),
             'direction': u'ingress', 'ethertype': u'IPv4',
@@ -534,7 +535,9 @@ def data(TEST):
             'protocol': u'icmp', 'remote_group_id': None,
             'remote_ip_prefix': u'0.0.0.0/0',
             'security_group_id': secgroup['id'],
-            'tenant_id': secgroup['tenant_id']}
+            'tenant_id': secgroup['tenant_id'],
+            'description': 'Ingress IPv4 ICMP',
+        }
         rule_group = {
             'id': uuidutils.generate_uuid(),
             'direction': u'ingress', 'ethertype': u'IPv4',
@@ -542,7 +545,9 @@ def data(TEST):
             'protocol': u'tcp', 'remote_group_id': sec_group_1['id'],
             'remote_ip_prefix': None,
             'security_group_id': secgroup['id'],
-            'tenant_id': secgroup['tenant_id']}
+            'tenant_id': secgroup['tenant_id'],
+            'description': 'Ingress HTTP from SG #1',
+        }
         rule_all_tcp = {
             'id': uuidutils.generate_uuid(),
             'direction': u'egress', 'ethertype': u'IPv4',
@@ -550,7 +555,9 @@ def data(TEST):
             'protocol': u'tcp', 'remote_group_id': None,
             'remote_ip_prefix': u'0.0.0.0/24',
             'security_group_id': secgroup['id'],
-            'tenant_id': secgroup['tenant_id']}
+            'tenant_id': secgroup['tenant_id'],
+            'description': 'Egress all TCP',
+        }
 
         rules = []
         if not default_only:
@@ -561,20 +568,18 @@ def data(TEST):
     add_rule_to_group(sec_group_1, default_only=False)
     add_rule_to_group(sec_group_2)
     add_rule_to_group(sec_group_3)
-    # NOTE: sec_group_empty is a SG without rules,
-    # so we don't call add_rule_to_group.
 
-    groups = [sec_group_1, sec_group_2, sec_group_3, sec_group_empty]
+    groups = [sec_group_1, sec_group_2, sec_group_3]
     sg_name_dict = dict([(sg['id'], sg['name']) for sg in groups])
     for sg in groups:
         # Neutron API.
         TEST.api_security_groups.add(sg)
-        for rule in sg.get('security_group_rules', []):
+        for rule in sg['security_group_rules']:
             TEST.api_security_group_rules.add(copy.copy(rule))
         # OpenStack Dashboard internaly API.
         TEST.security_groups.add(
             neutron.SecurityGroup(copy.deepcopy(sg), sg_name_dict))
-        for rule in sg.get('security_group_rules', []):
+        for rule in sg['security_group_rules']:
             TEST.security_group_rules.add(
                 neutron.SecurityGroupRule(copy.copy(rule), sg_name_dict))
 
@@ -629,7 +634,9 @@ def data(TEST):
         'subnet': {'used': 0, 'quota': 5},
         'port': {'used': 0, 'quota': 5},
         'router': {'used': 0, 'quota': 5},
-        'floatingip': {'used': 0, 'quota': 10},
+        'floatingip': {'used': 0, 'quota': 50},
+        'security_group': {'used': 0, 'quota': 20},
+        'security_group_rule': {'used': 0, 'quota': 100},
     }
     quota_usage = usage_quotas.QuotaUsage()
     for k, v in quota_usage_data.items():
